@@ -30,11 +30,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.28
+Version v3.0.29
 
 =cut
 
-our $VERSION = version->declare("v3.0.28");
+our $VERSION = version->declare("v3.0.29");
 
 =head1 SYNOPSIS
 
@@ -611,28 +611,8 @@ sub parse_license
 		}
 	}
 
-	# LLGPL
+	# NTP
 	given ($licensetext) {
-		when ( /$L{re}{llgpl}/ ) {
-			$gen_license->('llgpl');
-		}
-	}
-
-	# QPL
-	given ($licensetext) {
-		when ( /$L{re}{qpl}(?: $L{re}{version}{-keep})?/ ) {
-			$gen_license->( 'qpl', $1 );
-		}
-	}
-
-	# MIT
-	given ($licensetext) {
-		foreach my $id (qw<curl icu isc mit_advertising mit_enna mit_feh mit_new mit_old mit_oldstyle mit_oldstyle_disclaimer mit_oldstyle_permission>) {
-			when ( /$L{re}{$id}/) {
-				$gen_license->($id);
-				continue;
-			}
-		}
 		when ( /$L{re}{dsdp}/) {
 			$gen_license->('dsdp');
 		}
@@ -661,53 +641,11 @@ sub parse_license
 			}
 		}
 	}
-	elsif ( $licensetext =~ /licen[sc]ebsd(?:-(\d)-clause)?/i ) {
+	elsif ( $licensetext =~ /licen[sc]e:? ?bsd-(\d)-clause/i ) {
 		$gen_license->("bsd_${1}_clause");
 	}
-
-	# MPL
-	given ($licensetext) {
-		when ( /$L{re}{mpl},? \(?$L{re}{version}{-keep}\)?/ ) {
-			$gen_license->( 'mpl', $1 );
-		}
-	}
-
-	# APAFML
-	given ($licensetext) {
-		when ( /$L{re}{apafml}/ ) {
-			$gen_license->('apafml');
-		}
-	}
-
-	# Adobe-Glyph
-	given ($licensetext) {
-		when ( /$L{re}{'adobe_glyph'}/ ) {
-			$gen_license->('adobe_glyph');
-		}
-	}
-
-	# Adobe-2006
-	given ($licensetext) {
-		when ( /$L{re}{'adobe_2006'}/ ) {
-			$gen_license->('adobe_2006');
-		}
-	}
-
-	# Aladdin
-	given ($licensetext) {
-		when ( /This License is not the same as any of the GNU Licenses/ ) {
-			$gen_license->('Aladdin');
-		}
-		when ( /under the terms of the Aladdin Free Public License/ ) {
-			$gen_license->('Aladdin');
-		}
-	}
-
-	# GPL or Aladdin
-	given ($licensetext) {
-		when ( /under the GNU License and Aladdin Free Public License/ ) {
-			$gen_license->( 'GPL', 0, 0, 'Aladdin' );
-		}
+	elsif ( $licensetext =~ /licen[sc]e:? ?bsd\b/i ) {
+		$gen_license->('bsd');
 	}
 
 	# Artistic
@@ -722,6 +660,12 @@ sub parse_license
 
 	# Apache
 	given ($licensetext) {
+
+		# skip referenced license
+		when (/$L{re}{rpsl}/) {
+			break;
+		}
+
 		when ( /$L{re}{apache}(?:,? $L{re}{version}{-keep}(,? $L{re}{version_later_postfix})?)?(?:(?: or)? [^ ,]*?apache[^ ,]*| \([^(),]+\))*,? or $L{re}{gpl}(?: $L{re}{version}{-keep}(,? $L{re}{version_later_postfix})?)?/i ) {
 			$gen_license->( 'apache', $1, $2, 'gpl', $3, $4 );
 		}
@@ -742,27 +686,6 @@ sub parse_license
 		}
 	}
 
-	# Beerware
-	given ($licensetext) {
-		when ( /$L{re}{beerware}/i ) {
-			$gen_license->('beerware');
-		}
-	}
-
-	# FTL
-	given ($licensetext) {
-		when ( /$L{re}{ftl}/i ) {
-			$gen_license->('ftl');
-		}
-	}
-
-	# FSFAP
-	given ($licensetext) {
-		when ( /$L{re}{fsfap}/i ) {
-			$gen_license->('fsfap');
-		}
-	}
-
 	# FSFUL
 	given ($licensetext) {
 		when ( /$L{re}{fsful}/i ) {
@@ -824,20 +747,6 @@ sub parse_license
 		}
 	}
 
-	# SGI-B
-	given ($licensetext) {
-		when ( /$L{re}{sgi_b}(?:\s+\(?$L{re}{version}{-keep}\)?)?/ ) {
-			$gen_license->( 'sgi_b', $1 );
-		}
-	}
-
-	# public-domain
-	given ($licensetext) {
-		when ( /is in $L{re}{public_domain}/i ) {
-			$gen_license->('public_domain');
-		}
-	}
-
 	# CDDL
 	given ($licensetext) {
 		when ( /$L{re}{cddl}(?:,?\s+$L{re}{version}{-keep})?/ ) {
@@ -845,17 +754,10 @@ sub parse_license
 		}
 	}
 
-	# MS-PL
+	# public-domain
 	given ($licensetext) {
-		when ( /$L{re}{ms_pl}/ ) {
-			$gen_license->('ms_pl');
-		}
-	}
-
-	# MS-RL
-	given ($licensetext) {
-		when ( /$L{re}{ms_rl}/ ) {
-			$gen_license->('ms_rl');
+		when ( /is in $L{re}{public_domain}/i ) {
+			$gen_license->('public_domain');
 		}
 	}
 
@@ -886,78 +788,51 @@ sub parse_license
 			$gen_license->( 'BSL', $1, $2 );
 		}
 	}
-
-	# PostgreSQL
-	given ($licensetext) {
-		when ( /$L{re}{postgresql}/ ) {
-			$gen_license->('postgresql');
-		}
-	}
-
-	# Python
-	given ($licensetext) {
-		when ( /$L{re}{python}(?:,? $L{re}{version}{-keep})?/i ) {
-			$gen_license->( 'python', $1 );
-		}
-	}
-
-	# SIL
-	given ($licensetext) {
-		when ( /must be distributed using this license/i ) {
-			$gen_license->( 'SIL', '1.0' );
-		}
-		when ( /must be distributed entirely under this license/i ) {
-			$gen_license->( 'SIL', '1.1' );
-		}
-	}
-
-	# Unicode-strict
-	given ($licensetext) {
-		when ( /$L{re}{unicode_strict}/i ) {
-			$gen_license->('unicode_strict');
-		}
-	}
-
-	# Unicode-TOU
-	given ($licensetext) {
-		when ( /$L{re}{unicode_tou}/i ) {
-			$gen_license->('unicode_tou');
-		}
-	}
-
-	# Zlib/Libpng
-	given ($licensetext) {
-		when ( /$L{re}{'zlib_acknowledgement'}/ ) {
-			$gen_license->('zlib_acknowledgement');
-		}
-		when ( /$L{re}{cube}/ ) {
-			$gen_license->('cube');
-		}
-		when ( /$L{re}{eurosym}/ ) {
-			$gen_license->('eurosym');
-		}
-		when ( /$L{re}{zlib}/ ) {
-			$gen_license->('zlib');
-		}
-		when ( /see copyright notice in zlib\.h/ ) {
-			$gen_license->('zlib');
-		}
-		when ( /This code is released under $L{re}{libpng}/ ) {
-			$gen_license->('libpng');
-		}
-	}
-
-	# WTFPL
-	given ($licensetext) {
-		when ( /$L{re}{wtfpl},? $L{re}{version}{-keep}/i ) {
-			$gen_license->( 'wtfpl', $1 );
-		}
-	}
 	#>>>
 
+	given ($licensetext) {
+
+		# simple-versioned
+		foreach my $id (qw<mpl ofl python qpl rpsl sgi_b wtfpl>) {
+			when (/$L{re}{$id}\W*\(?$L{re}{version}{-keep}\)?/) {
+
+				# skip referenced license
+				if ( 'mpl' eq $id and $licensetext =~ /$L{re}{rpsl}/ ) {
+					continue;
+				}
+
+				$gen_license->( $id, $1 );
+				continue;
+			}
+		}
+
+		# unversioned
+		foreach my $id (
+			qw(
+			adobe_2006 adobe_glyph aladdin apafml
+			beerware cube curl eurosym fsfap ftl icu isc libpng llgpl
+			mit_advertising mit_cmu mit_cmu_warranty
+			mit_enna mit_feh mit_new mit_old
+			mit_oldstyle mit_oldstyle_disclaimer mit_oldstyle_permission
+			ms_pl ms_rl postgresql unicode_strict unicode_tou
+			zlib zlib_acknowledgement)
+			)
+		{
+			when (/$L{re}{$id}/) {
+
+				# skip embedded license
+				if ( 'zlib' eq $id and $licensetext =~ /$L{re}{cube}/ ) {
+					continue;
+				}
+				$gen_license->($id);
+				continue;
+			}
+		}
+	}
+
 	# Remove trailing spaces.
 	$license =~ s/\s+$//;
-	return $self->deb_fmt ? join( ' and/or ', @spdx_license ) : $license;
+	return $self->deb_fmt ? join( ' and/or ', sort @spdx_license ) : $license;
 }
 
 =encoding UTF-8
